/*
 * C to C Handler
 * 
 * Author: Anton Prozorov <prozanton@gmail.com>
 * 
 * Copyright 2011-2022, ZDevs
 * 
 */

#include "c2cBridge.h"

#include <stdio.h>
#include <sys/poll.h>

#include <android/log.h>
#define APP_NAME "coreutils"

static int process;
static time_t process_time;

void jSetProcessPercent(int iProc)
{
	if (process == iProc)
		return;
	if (iProc != 100 && time(NULL) - process_time < 2)
		return;
	
	process = iProc;
	process_time = time(NULL);

	printf(C2C_MAGIC_CHAR "PP\t%d\n", iProc);
	fflush(stdout);
}

void jSetProcessText(const char *sName)
{
	process = 0;
	process_time = 0;

	printf(C2C_MAGIC_CHAR "PT\t%s\n", sName);
	fflush(stdout);
}

static int overwrite_all;

int jAskOverwrite(const char *sExistName, long iExistSize, int iExistTime,
		const char *sNewName, long iNewSize, int iNewTime)
{
	char line[255];
	
	if (overwrite_all)
		return overwrite_all;

	printf(C2C_MAGIC_CHAR "AO\t%ld\t%d\t%ld\t%d\t%s\n", iExistSize, iExistTime, iNewSize, iNewTime, sNewName);
	fflush(stdout);
	
	while (fgets(line, sizeof(line), stdin))
	{
		if (line[0] != '$')
			continue;
		
		int i, answer = 0;
		for (i=1; i<10 && line[i]; i++)
		{
			switch (line[i])
			{
				case 'Y':
					answer |= ANSWER_YES;
					break;
				case 'N':
					answer |= ANSWER_NO;
					break;
				case 'R':
					answer |= ANSWER_AUTO_RENAME;
					break;
				case 'C':
					answer |= ANSWER_CANCEL;
					break;
				case 'A':
					answer |= ANSWER_TO_ALL;
					break;
			}
		}
		
		if (answer&ANSWER_TO_ALL)
		{
			overwrite_all = (answer&(~ANSWER_TO_ALL));
			answer = overwrite_all;
		}
		
		return answer;
	}

	return ANSWER_CANCEL;
}

static int is_cancel;

int jGetStatus()
{
	struct pollfd fds;
	int ret;

	fds.fd = 0; // STDIN
	fds.events = POLLIN;
	ret = poll(&fds, 1, 0);
	if(ret == 1)
	{
		char line[255];

		if (fgets(line, sizeof(line), stdin) && line[0] == '$')
		{
			if (line[1] == 'C')
				is_cancel = STATUS_CANCEL;
		}
	}

	return is_cancel;
}

void jInit()
{
	is_cancel = 0;
	overwrite_all = 0;
}
