/* vi: set sw=4 ts=4: */
/*
 * Busybox main internal header file
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Based in part on code from sash, Copyright (c) 1999 by David I. Bell 
 * Permission has been granted to redistribute this code under the GPL.
 *
 */
#ifndef	__LIBBB_H__
#define	__LIBBB_H__    1

#include <stdio.h>
#include <stdarg.h>
#include <sys/stat.h>
#include <sys/types.h>

/* Some useful definitions */
#define FALSE   ((int) 0)
#define TRUE    ((int) 1)
#define SKIP	((int) 2)

#define BUF_SIZE        8192
#define EXPAND_ALLOC    1024

/* Macros for min/max.  */
#ifndef MIN
#define	MIN(a,b) (((a)<(b))?(a):(b))
#endif

#ifndef MAX
#define	MAX(a,b) (((a)>(b))?(a):(b))
#endif

#ifndef ANDROID_ZA_UI
extern void error_msg(const char *s, ...);
extern void perror_msg(const char *s, ...);
extern void perror_msg_and_die(const char *s, ...);
#else
#define error_msg(...)  __android_log_print(ANDROID_LOG_ERROR, APP_NAME, __VA_ARGS__)
#define perror_msg(...)  __android_log_print(ANDROID_LOG_ERROR, APP_NAME, __VA_ARGS__)
#define perror_msg_and_die(...)  {__android_log_print(ANDROID_LOG_ERROR, APP_NAME, __VA_ARGS__); \
	exit(EXIT_FAILURE); }
#endif

const char *mode_string(int mode);

int remove_file(const char *path, int flags);
#ifdef ANDROID_ZA_UI
int copy_file(const char *source, const char *dest, int flags, size_t start_len);
#else
int copy_file(const char *source, const char *dest, int flags);
#endif
int copy_file_chunk(FILE *src_file, FILE *dst_file, unsigned long long chunksize);

extern char *get_last_path_component(char *path);

char *concat_path_file(const char *path, const char *filename);
char *last_char_is(const char *s, int c);

char *xreadlink(const char *path);

int recursive_action(const char *fileName, int recurse, int followLinks, int depthFirst,
	  int (*fileAction) (const char *fileName, struct stat* statbuf, void* userData, int depth),
	  int (*dirAction) (const char *fileName, struct stat* statbuf, void* userData, int depth),
	  void* userData, int depth);

enum {
	FILEUTILS_PRESERVE_STATUS = 1,
	FILEUTILS_PRESERVE_SYMLINKS = 2,
	FILEUTILS_RECUR = 4,
	FILEUTILS_FORCE = 8,
	FILEUTILS_INTERACTIVE = 16
};

#ifdef ANDROID_ZA_UI
#include <android/log.h>
#define APP_NAME "coreutils"
#endif

#endif /* __LIBBB_H__ */
